#! /usr/bin/env bash

function test_bluer_journal_git_pull() {
    if [[ "$BLUER_AI_WEB_STATUS" != online ]]; then
        bluer_ai_log_warning "internet is not online, test is disabled."
        return
    fi

    local options=$1

    bluer_journal_git_pull
}
